.. Gate Set Tomography documentation master file, created by
   sphinx-quickstart on Thu Jun  4 13:16:14 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyGSTi's documentation
=================================

**pyGSTi** is a python implementation of Gate Set Tomography (GST).

Packages
--------

.. autosummary::
   :template: pygsti_autosummary.rst
   :toctree:

   pygsti


.. 
   NOT NEEDED b/c theme has sidebar with expandable contents
   Contents
   --------
   XX.. toctree::
   XX   :maxdepth: 2

       GST
       Commons



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

